@@ -15,7 +15,7 @@ from nemdata.nemde import download_nemde
 @click.option("--start", "-s", default="2018-01", help="start date (YYYY-MM)")
 @click.option("--end", "-e", default="2018-03", help="end date (incusive) (YYYY-MM)")
 def cli(start, end, report):
-    """nemdata is a tool to access NEM data"""
+    """nemdata is a tool to access NEM data from AEMO."""
     print(":wave: from nemdata\n")
     download(start, end, report)
 
